==> pyomo-5.5.1-py36_1001.tar.bz2: info/test/run_test.py <==
print("import: 'pyomo'")
import pyomo

print("import: 'pyomo.bilevel'")
import pyomo.bilevel

print("import: 'pyomo.bilevel.plugins'")
import pyomo.bilevel.plugins

print("import: 'pyomo.checker'")
import pyomo.checker

print("import: 'pyomo.checker.plugins'")
import pyomo.checker.plugins

print("import: 'pyomo.checker.plugins.checkers'")
import pyomo.checker.plugins.checkers

print("import: 'pyomo.checker.plugins.checkers.model'")
import pyomo.checker.plugins.checkers.model

print("import: 'pyomo.checker.plugins.checkers.py3k'")
import pyomo.checker.plugins.checkers.py3k

print("import: 'pyomo.checker.plugins.checkers.sample'")
import pyomo.checker.plugins.checkers.sample

print("import: 'pyomo.contrib'")
import pyomo.contrib

print("import: 'pyomo.contrib.example'")
import pyomo.contrib.example

print("import: 'pyomo.contrib.example.plugins'")
import pyomo.contrib.example.plugins

print("import: 'pyomo.contrib.gdpopt'")
import pyomo.contrib.gdpopt

print("import: 'pyomo.contrib.preprocessing'")
import pyomo.contrib.preprocessing

print("import: 'pyomo.contrib.preprocessing.plugins'")
import pyomo.contrib.preprocessing.plugins

print("import: 'pyomo.contrib.trustregion'")
import pyomo.contrib.trustregion

print("import: 'pyomo.core'")
import pyomo.core

print("import: 'pyomo.core.base'")
import pyomo.core.base

print("import: 'pyomo.core.beta'")
import pyomo.core.beta

print("import: 'pyomo.core.data'")
import pyomo.core.data

print("import: 'pyomo.core.kernel'")
import pyomo.core.kernel

print("import: 'pyomo.core.kernel.component_piecewise'")
import pyomo.core.kernel.component_piecewise

print("import: 'pyomo.core.plugins'")
import pyomo.core.plugins

print("import: 'pyomo.core.plugins.data'")
import pyomo.core.plugins.data

print("import: 'pyomo.core.plugins.transform'")
import pyomo.core.plugins.transform

print("import: 'pyomo.core.preprocess'")
import pyomo.core.preprocess

print("import: 'pyomo.dae'")
import pyomo.dae

print("import: 'pyomo.dae.plugins'")
import pyomo.dae.plugins

print("import: 'pyomo.environ'")
import pyomo.environ

print("import: 'pyomo.gdp'")
import pyomo.gdp

print("import: 'pyomo.gdp.plugins'")
import pyomo.gdp.plugins

print("import: 'pyomo.kernel'")
import pyomo.kernel

print("import: 'pyomo.mpec'")
import pyomo.mpec

print("import: 'pyomo.mpec.plugins'")
import pyomo.mpec.plugins

print("import: 'pyomo.neos'")
import pyomo.neos

print("import: 'pyomo.neos.plugins'")
import pyomo.neos.plugins

print("import: 'pyomo.opt'")
import pyomo.opt

print("import: 'pyomo.opt.base'")
import pyomo.opt.base

print("import: 'pyomo.opt.blackbox'")
import pyomo.opt.blackbox

print("import: 'pyomo.opt.parallel'")
import pyomo.opt.parallel

print("import: 'pyomo.opt.plugins'")
import pyomo.opt.plugins

print("import: 'pyomo.opt.problem'")
import pyomo.opt.problem

print("import: 'pyomo.opt.results'")
import pyomo.opt.results

print("import: 'pyomo.opt.solver'")
import pyomo.opt.solver

print("import: 'pyomo.opt.testing'")
import pyomo.opt.testing

print("import: 'pyomo.pysp'")
import pyomo.pysp

print("import: 'pyomo.pysp.convert'")
import pyomo.pysp.convert

print("import: 'pyomo.pysp.plugins'")
import pyomo.pysp.plugins

print("import: 'pyomo.pysp.scenariotree'")
import pyomo.pysp.scenariotree

print("import: 'pyomo.pysp.solvers'")
import pyomo.pysp.solvers

print("import: 'pyomo.pysp.util'")
import pyomo.pysp.util

print("import: 'pyomo.repn'")
import pyomo.repn

print("import: 'pyomo.repn.beta'")
import pyomo.repn.beta

print("import: 'pyomo.repn.plugins'")
import pyomo.repn.plugins

print("import: 'pyomo.repn.plugins.ampl'")
import pyomo.repn.plugins.ampl

print("import: 'pyomo.scripting'")
import pyomo.scripting

print("import: 'pyomo.scripting.plugins'")
import pyomo.scripting.plugins

print("import: 'pyomo.solvers'")
import pyomo.solvers

print("import: 'pyomo.solvers.plugins'")
import pyomo.solvers.plugins

print("import: 'pyomo.solvers.plugins.converter'")
import pyomo.solvers.plugins.converter

print("import: 'pyomo.solvers.plugins.smanager'")
import pyomo.solvers.plugins.smanager

print("import: 'pyomo.solvers.plugins.solvers'")
import pyomo.solvers.plugins.solvers

print("import: 'pyomo.solvers.plugins.testdriver'")
import pyomo.solvers.plugins.testdriver

print("import: 'pyomo.util'")
import pyomo.util

print("import: 'pyomo.version'")
import pyomo.version

==> pyomo-5.6.1-py36_2.tar.bz2: info/test/run_test.py <==
print("import: 'pyomo'")
import pyomo

print("import: 'pyomo.bilevel'")
import pyomo.bilevel

print("import: 'pyomo.bilevel.plugins'")
import pyomo.bilevel.plugins

print("import: 'pyomo.checker'")
import pyomo.checker

print("import: 'pyomo.checker.plugins'")
import pyomo.checker.plugins

print("import: 'pyomo.checker.plugins.checkers'")
import pyomo.checker.plugins.checkers

print("import: 'pyomo.checker.plugins.checkers.model'")
import pyomo.checker.plugins.checkers.model

print("import: 'pyomo.checker.plugins.checkers.py3k'")
import pyomo.checker.plugins.checkers.py3k

print("import: 'pyomo.checker.plugins.checkers.sample'")
import pyomo.checker.plugins.checkers.sample

print("import: 'pyomo.common'")
import pyomo.common

print("import: 'pyomo.contrib'")
import pyomo.contrib

print("import: 'pyomo.contrib.example'")
import pyomo.contrib.example

print("import: 'pyomo.contrib.example.plugins'")
import pyomo.contrib.example.plugins

print("import: 'pyomo.contrib.gdp_bounds'")
import pyomo.contrib.gdp_bounds

print("import: 'pyomo.contrib.gdp_bounds.plugins'")
import pyomo.contrib.gdp_bounds.plugins

print("import: 'pyomo.contrib.gdpopt'")
import pyomo.contrib.gdpopt

print("import: 'pyomo.contrib.mcpp'")
import pyomo.contrib.mcpp

print("import: 'pyomo.contrib.multistart'")
import pyomo.contrib.multistart

print("import: 'pyomo.contrib.parmest'")
import pyomo.contrib.parmest

print("import: 'pyomo.contrib.parmest.examples'")
import pyomo.contrib.parmest.examples

print("import: 'pyomo.contrib.parmest.examples.mea'")
import pyomo.contrib.parmest.examples.mea

print("import: 'pyomo.contrib.parmest.examples.rooney_biegler'")
import pyomo.contrib.parmest.examples.rooney_biegler

print("import: 'pyomo.contrib.parmest.examples.semibatch'")
import pyomo.contrib.parmest.examples.semibatch

print("import: 'pyomo.contrib.preprocessing'")
import pyomo.contrib.preprocessing

print("import: 'pyomo.contrib.preprocessing.plugins'")
import pyomo.contrib.preprocessing.plugins

print("import: 'pyomo.contrib.sensitivity_toolbox'")
import pyomo.contrib.sensitivity_toolbox

print("import: 'pyomo.contrib.sensitivity_toolbox.examples'")
import pyomo.contrib.sensitivity_toolbox.examples

print("import: 'pyomo.contrib.trustregion'")
import pyomo.contrib.trustregion

print("import: 'pyomo.core'")
import pyomo.core

print("import: 'pyomo.core.base'")
import pyomo.core.base

print("import: 'pyomo.core.beta'")
import pyomo.core.beta

print("import: 'pyomo.core.expr'")
import pyomo.core.expr

print("import: 'pyomo.core.kernel'")
import pyomo.core.kernel

print("import: 'pyomo.core.kernel.piecewise_library'")
import pyomo.core.kernel.piecewise_library

print("import: 'pyomo.core.plugins'")
import pyomo.core.plugins

print("import: 'pyomo.core.plugins.transform'")
import pyomo.core.plugins.transform

print("import: 'pyomo.core.preprocess'")
import pyomo.core.preprocess

print("import: 'pyomo.dae'")
import pyomo.dae

print("import: 'pyomo.dae.plugins'")
import pyomo.dae.plugins

print("import: 'pyomo.dataportal'")
import pyomo.dataportal

print("import: 'pyomo.dataportal.plugins'")
import pyomo.dataportal.plugins

print("import: 'pyomo.duality'")
import pyomo.duality

print("import: 'pyomo.environ'")
import pyomo.environ

print("import: 'pyomo.gdp'")
import pyomo.gdp

print("import: 'pyomo.gdp.plugins'")
import pyomo.gdp.plugins

print("import: 'pyomo.kernel'")
import pyomo.kernel

print("import: 'pyomo.mpec'")
import pyomo.mpec

print("import: 'pyomo.mpec.plugins'")
import pyomo.mpec.plugins

print("import: 'pyomo.neos'")
import pyomo.neos

print("import: 'pyomo.neos.plugins'")
import pyomo.neos.plugins

print("import: 'pyomo.network'")
import pyomo.network

print("import: 'pyomo.network.plugins'")
import pyomo.network.plugins

print("import: 'pyomo.opt'")
import pyomo.opt

print("import: 'pyomo.opt.base'")
import pyomo.opt.base

print("import: 'pyomo.opt.blackbox'")
import pyomo.opt.blackbox

print("import: 'pyomo.opt.parallel'")
import pyomo.opt.parallel

print("import: 'pyomo.opt.plugins'")
import pyomo.opt.plugins

print("import: 'pyomo.opt.problem'")
import pyomo.opt.problem

print("import: 'pyomo.opt.results'")
import pyomo.opt.results

print("import: 'pyomo.opt.solver'")
import pyomo.opt.solver

print("import: 'pyomo.opt.testing'")
import pyomo.opt.testing

print("import: 'pyomo.pysp'")
import pyomo.pysp

print("import: 'pyomo.pysp.convert'")
import pyomo.pysp.convert

print("import: 'pyomo.pysp.plugins'")
import pyomo.pysp.plugins

print("import: 'pyomo.pysp.scenariotree'")
import pyomo.pysp.scenariotree

print("import: 'pyomo.pysp.solvers'")
import pyomo.pysp.solvers

print("import: 'pyomo.pysp.util'")
import pyomo.pysp.util

print("import: 'pyomo.repn'")
import pyomo.repn

print("import: 'pyomo.repn.beta'")
import pyomo.repn.beta

print("import: 'pyomo.repn.plugins'")
import pyomo.repn.plugins

print("import: 'pyomo.repn.plugins.ampl'")
import pyomo.repn.plugins.ampl

print("import: 'pyomo.scripting'")
import pyomo.scripting

print("import: 'pyomo.scripting.plugins'")
import pyomo.scripting.plugins

print("import: 'pyomo.solvers'")
import pyomo.solvers

print("import: 'pyomo.solvers.plugins'")
import pyomo.solvers.plugins

print("import: 'pyomo.solvers.plugins.converter'")
import pyomo.solvers.plugins.converter

print("import: 'pyomo.solvers.plugins.smanager'")
import pyomo.solvers.plugins.smanager

print("import: 'pyomo.solvers.plugins.solvers'")
import pyomo.solvers.plugins.solvers

print("import: 'pyomo.solvers.plugins.testdriver'")
import pyomo.solvers.plugins.testdriver

print("import: 'pyomo.util'")
import pyomo.util

print("import: 'pyomo.version'")
import pyomo.version
